==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/redstone/displayLink/target/LecternDisplayTarget.java <==
package com.zurrtum.create.content.redstone.displayLink.target;

import com.zurrtum.create.api.behaviour.display.DisplayHolder;
import com.zurrtum.create.api.behaviour.display.DisplayTarget;
import com.zurrtum.create.content.redstone.displayLink.DisplayLinkContext;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2586;
import net.minecraft.class_3722;
import net.minecraft.class_5250;
import net.minecraft.class_9262;
import net.minecraft.class_9301;
import net.minecraft.class_9302;
import net.minecraft.class_9334;

public class LecternDisplayTarget extends DisplayTarget {

    @Override
    public void acceptText(int line, List<class_5250> text, DisplayLinkContext context) {
        class_2586 be = context.getTargetBlockEntity();
        if (!(be instanceof class_3722 lectern))
            return;
        class_1799 book = lectern.method_17520();
        if (book.method_7960())
            return;

        if (book.method_31574(class_1802.field_8674))
            lectern.method_17513(book = signBook(book));
        if (!book.method_31574(class_1802.field_8360))
            return;

        class_9302 writtenBookContent = book.method_58695(class_9334.field_49606, class_9302.field_49829);
        List<class_9262<class_2561>> pages = new ArrayList<>(writtenBookContent.comp_2422());

        boolean changed = false;
        DisplayHolder holder = (DisplayHolder) lectern;
        for (int i = 0; i - line < text.size() && i < 50; i++) {
            if (pages.size() <= i)
                pages.add(class_9262.method_57137(i < line ? class_2561.method_43473() : text.get(i - line)));

            else if (i >= line) {
                if (i - line == 0)
                    reserve(i, holder, context);
                if (i - line > 0 && isReserved(i - line, holder, context))
                    break;

                pages.set(i, class_9262.method_57137(text.get(i - line)));
            }
            changed = true;
        }

        book.method_57379(class_9334.field_49606, writtenBookContent.method_58188(pages));
        lectern.method_17513(book);

        if (changed)
            context.level().method_8413(context.getTargetPos(), lectern.method_11010(), lectern.method_11010(), 2);
    }

    @Override
    public DisplayTargetStats provideStats(DisplayLinkContext context) {
        return new DisplayTargetStats(50, 256, this);
    }

    public class_2561 getLineOptionText(int line) {
        return class_2561.method_43469("create.display_target.page", line + 1);
    }

    private class_1799 signBook(class_1799 book) {
        class_1799 written = new class_1799(class_1802.field_8360);
        class_9301 bookContents = book.method_58694(class_9334.field_49653);

        List<class_9262<class_2561>> list = bookContents.comp_2422().stream().map(filterable -> filterable.<class_2561>method_57138(class_2561::method_43470)).toList();
        class_9302 writtenContent = new class_9302(class_9262.method_57137("Printed Book"), "Data Gatherer", 0, list, true);
        written.method_57379(class_9334.field_49606, writtenContent);

        return written;
    }

    @Override
    public boolean requiresComponentSanitization() {
        return true;
    }

}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/content/redstone/displayLink/target/LecternDisplayTarget.java <==
package com.zurrtum.create.content.redstone.displayLink.target;

import com.zurrtum.create.api.behaviour.display.DisplayHolder;
import com.zurrtum.create.api.behaviour.display.DisplayTarget;
import com.zurrtum.create.content.redstone.displayLink.DisplayLinkContext;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_2561;
import net.minecraft.class_2586;
import net.minecraft.class_3722;
import net.minecraft.class_5250;
import net.minecraft.class_9262;
import net.minecraft.class_9301;
import net.minecraft.class_9302;
import net.minecraft.class_9334;

public class LecternDisplayTarget extends DisplayTarget {

    @Override
    public void acceptText(int line, List<class_5250> text, DisplayLinkContext context) {
        class_2586 be = context.getTargetBlockEntity();
        if (!(be instanceof class_3722 lectern))
            return;
        class_1799 book = lectern.method_17520();
        if (book.method_7960())
            return;

        if (book.method_31574(class_1802.field_8674))
            lectern.method_17513(book = signBook(book));
        if (!book.method_31574(class_1802.field_8360))
            return;

        class_9302 writtenBookContent = book.method_58695(
            class_9334.field_49606,
            class_9302.field_49829
        );
        List<class_9262<class_2561>> pages = new ArrayList<>(writtenBookContent.comp_2422());

        boolean changed = false;
        DisplayHolder holder = (DisplayHolder) lectern;
        for (int i = 0; i - line < text.size() && i < 50; i++) {
            if (pages.size() <= i)
                pages.add(class_9262.method_57137(i < line ? class_2561.method_43473() : text.get(i - line)));

            else if (i >= line) {
                if (i - line == 0)
                    reserve(i, holder, context);
                if (i - line > 0 && isReserved(i - line, holder, context))
                    break;

                pages.set(i, class_9262.method_57137(text.get(i - line)));
            }
            changed = true;
        }

        book.method_57379(class_9334.field_49606, writtenBookContent.method_58188(pages));
        lectern.method_17513(book);

        if (changed)
            context.level().method_8413(context.getTargetPos(), lectern.method_11010(), lectern.method_11010(), 2);
    }

    @Override
    public DisplayTargetStats provideStats(DisplayLinkContext context) {
        return new DisplayTargetStats(50, 256, this);
    }

    public class_2561 getLineOptionText(int line) {
        return class_2561.method_43469("create.display_target.page", line + 1);
    }

    private class_1799 signBook(class_1799 book) {
        class_1799 written = new class_1799(class_1802.field_8360);
        class_9301 bookContents = book.method_58694(class_9334.field_49653);

        List<class_9262<class_2561>> list = bookContents.comp_2422().stream().map(filterable -> filterable.<class_2561>method_57138(class_2561::method_43470)).toList();
        class_9302 writtenContent = new class_9302(
            class_9262.method_57137("Printed Book"),
            "Data Gatherer",
            0,
            list,
            true
        );
        written.method_57379(class_9334.field_49606, writtenContent);

        return written;
    }

    @Override
    public boolean requiresComponentSanitization() {
        return true;
    }

}
